// ****************************************************************** 
//       * Functions triggered by events in client user interface
// ******************************************************************

// ************************************************************************************
// Name   : client_SetIpBootMode()
// Purpose: Called when user selects a boot mode.
//          This function extracts the combo box value and sends the value to the server.
// Inputs : NONE
// Outputs: NONE
function client_SetIpBootMode()
{
   var anElement = document.getElementById( 'bootModeSelect' );
   if ( anElement )	        // Set boot mode
      serverSetIpIntf.SetIpBootMode(parseInt(anElement.value, 10));
};

// ************************************************************************************
// Name   : client_SetIpSiteStatusUpdate()
// Purpose: Called when the current page loads
// Inputs : NONE
// Outputs: NONE
function client_SetIpSiteStatusUpdate()
{
   Initialize_SetIpSite();
   client_SetIpStatusUpdate();
};

// ************************************************************************************
// Name   : client_SetIpStatusUpdate()
// Purpose: Called when the current page loads
// Inputs : NONE
// Outputs: NONE
function client_SetIpStatusUpdate()
{
   serverSetIpIntf.SetIpSelectContentUpdate();
   serverSetIpIntf.SetIpStatusUpdate();
};

// ****************************************************************** 
// * Functions called asynchronously from the server.
// ******************************************************************

function asyncUpdateSetIpBootModeStatus(aBootMode)
{
   var anElement = document.getElementById( 'bootModeSelect' );
   if ( anElement )	        // Set boot mode
      anElement.value = aBootMode;
}

function asyncUpdateSetIpServerIpAddressStatus(aServerIpAddress)
{
   var anElement = document.getElementById( 'serverIpAddressInput' );
   if ( anElement )	        // Set server IP address
   {
      var addr1 = (aServerIpAddress & 0xFF000000) >> 24;
      var addr2 = (aServerIpAddress & 0xFF0000) >> 16;
      var addr3 = (aServerIpAddress & 0xFF00) >> 8;
      var addr4 = (aServerIpAddress & 0xFF);
      addr1 = (addr1 < 0) ? (addr1 + 256) : addr1;
      addr2 = (addr2 < 0) ? (addr2 + 256) : addr2;
      addr3 = (addr3 < 0) ? (addr3 + 256) : addr3;
      addr4 = (addr4 < 0) ? (addr4 + 256) : addr4;
      anElement.value = addr1 + "." + addr2 + "." + addr3 + "." + addr4;
   }
}

function asyncUpdateSetIpRouterIpAddressStatus(aRouterIpAddress)
{
   var anElement = document.getElementById( 'routerIpAddressInput' );
   if ( anElement )	        // Set router IP address
   {
      var addr1 = (aRouterIpAddress & 0xFF000000) >> 24;
      var addr2 = (aRouterIpAddress & 0xFF0000) >> 16;
      var addr3 = (aRouterIpAddress & 0xFF00) >> 8;
      var addr4 = (aRouterIpAddress & 0xFF);
      addr1 = (addr1 < 0) ? (addr1 + 256) : addr1;
      addr2 = (addr2 < 0) ? (addr2 + 256) : addr2;
      addr3 = (addr3 < 0) ? (addr3 + 256) : addr3;
      addr4 = (addr4 < 0) ? (addr4 + 256) : addr4;
      anElement.value = addr1 + "." + addr2 + "." + addr3 + "." + addr4;
   }
}

function asyncUpdateSetIpAddressMaskStatus(anIpAddressMask)
{
   var anElement = document.getElementById( 'ipAddressMaskInput' );
   if ( anElement )	        // Set IP address mask
   {
      var addr1 = (anIpAddressMask & 0xFF000000) >> 24;
      var addr2 = (anIpAddressMask & 0xFF0000) >> 16;
      var addr3 = (anIpAddressMask & 0xFF00) >> 8;
      var addr4 = (anIpAddressMask & 0xFF);
      addr1 = (addr1 < 0) ? (addr1 + 256) : addr1;
      addr2 = (addr2 < 0) ? (addr2 + 256) : addr2;
      addr3 = (addr3 < 0) ? (addr3 + 256) : addr3;
      addr4 = (addr4 < 0) ? (addr4 + 256) : addr4;
      anElement.value = addr1 + "." + addr2 + "." + addr3 + "." + addr4;
   }
}

function asyncUpdateSetIpModemIpAddressStatus(aModemIpAddress)
{
   var anElement = document.getElementById( 'modemIpAddressInput' );
   if ( anElement )	        // Set modem IP address
   {
      var addr1 = (aModemIpAddress & 0xFF000000) >> 24;
      var addr2 = (aModemIpAddress & 0xFF0000) >> 16;
      var addr3 = (aModemIpAddress & 0xFF00) >> 8;
      var addr4 = (aModemIpAddress & 0xFF);
      addr1 = (addr1 < 0) ? (addr1 + 256) : addr1;
      addr2 = (addr2 < 0) ? (addr2 + 256) : addr2;
      addr3 = (addr3 < 0) ? (addr3 + 256) : addr3;
      addr4 = (addr4 < 0) ? (addr4 + 256) : addr4;
      anElement.value = addr1 + "." + addr2 + "." + addr3 + "." + addr4;
   }
}

// ********************************************************************************

function validateIpForm(form)
{      
   if (IsValidIpAddress(form.setup_ServerIpAddress))
   {
      if (IsValidIpAddress(form.setup_RouterIpAddress))
      {
         if (IsValidIpAddress(form.setup_IpAddressMask))
         {
            if (IsValidIpAddress(form.setup_ModemIpAddress))
               return(true);
         }
      }
   }
   return(false);
};

// ****************************************************************** 
// * Functions to update the select content.
// ******************************************************************

function asyncUpdateSetIpBootModeSelectContent(aSelectContent)
{
   var anElement = document.getElementById('bootModeSelect');
   if ( anElement )
      Update_Element_Select_Content( anElement, aSelectContent );
}
